@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #     LICENSE: The GNU Public License v3 or Greater
 #
-#     WordTeX (wordtex) v0.2.1
+#     WordTeX (wordtex) v0.2.21
 #     Copyright 2013 Garrett Berg
 #     
 #     Loosly based on LaTeX2WP version 0.6.2, Luca Trevisan Copyright 2009
@@ -22,6 +22,9 @@
 
 from distutils.core import setup
 import publish
+ctb_packages = ['cloudtb', 'cloudtb.extra', 'cloudtb.extra.PyQt', 
+                  'cloudtb.tests', 'cloudtb.external',]
+ctb_packages = ['wordtex.' + n for n in ctb_packages]
 setup(name='wordtex',
       version=publish.VERSION,
       description='Latex to Word Press HTML converter',
@@ -29,8 +32,9 @@ setup(name='wordtex',
       author_email='garrett@cloudformdesign.com',
       url='https://github.com/cloudformdesign/wordtex',
 #          modules = ['wordtex', 'wp_formatting', 'texlib'],
-      packages = ['wordtex', 'wordtex.cloudtb',],
-      package_dir = {'wordtex': '_publish'}
+      packages = ['wordtex',]+
+                  ctb_packages,
+      package_dir = {'': '_publish'}
 #      packages=['wordtex', 'wordtex.cloudtb'],
      )
     
\ No newline at end of file
